@@ -5,7 +5,7 @@ use warnings;
 
 use Alien::Base::PkgConfig;
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -379,12 +379,31 @@ L<Alien::Base::ModuleBuild::API#CONSTRUCTOR> for all build arguments).
 
 sub dynamic_libs {
   my ($class) = @_;
-  my $dir = File::Spec->catfile($class->dist_dir, 'dynamic');
-  return unless -d $dir;
-  opendir(my $dh, $dir);
-  my @dlls = grep { /\.so/ || /\.(dylib|dll)$/ } grep !/^\./, readdir $dh;
-  closedir $dh;
-  grep { ! -l $_ } map { File::Spec->catfile($dir, $_) } @dlls;
+  
+  if($class->install_type('system')) {
+
+    my $name = $class->config('ffi_name');
+    unless(defined $name) {
+      $name = $class->config('name');
+      # strip leading lib from things like libarchive or libffi
+      $name =~ s/^lib//;
+      # strip trailing version numbers
+      $name =~ s/-[0-9\.]+$//;
+    }
+    
+    require FFI::CheckLib;  
+    return FFI::CheckLib::find_lib(lib => $name);
+  
+  } else {
+  
+    my $dir = File::Spec->catfile($class->dist_dir, 'dynamic');
+    return unless -d $dir;
+    opendir(my $dh, $dir);
+    my @dlls = grep { /\.so/ || /\.(dylib|dll)$/ } grep !/^\./, readdir $dh;
+    closedir $dh;
+    return grep { ! -l $_ } map { File::Spec->catfile($dir, $_) } @dlls;
+
+  }
 }
 
 =head2 bin_dir
@@ -489,7 +508,9 @@ L<Alien>
 
 =head1 AUTHOR
 
-Joel Berger, E<lt>joel.a.berger@gmail.comE<gt>
+Original author: Joel Berger, E<lt>joel.a.berger@gmail.comE<gt>
+
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt> and the L<Alien::Base> team
 
 =head1 CONTRIBUTORS
 
@@ -515,7 +536,7 @@ Joel Berger, E<lt>joel.a.berger@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2014 by Joel Berger
+Copyright (C) 2012-2015 by Joel Berger
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
