@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -54,9 +54,12 @@ $Force = $ENV{ALIEN_FORCE} if defined $ENV{ALIEN_FORCE};
 
 ## Extra parameters in A::B::MB objects (all (toplevel) should start with 'alien_')
 
-# alien_name: name of library 
+# alien_name: name of library (pkg-config)
 __PACKAGE__->add_property('alien_name');
 
+# alien_ffi_name: name of library (the "foo" in libfoo)
+__PACKAGE__->add_property('alien_ffi_name');
+
 # alien_temp_dir: folder name for download/build
 __PACKAGE__->add_property( alien_temp_dir => '_alien' );
 
@@ -155,19 +158,21 @@ sub new {
   # be used by the auto_include method
   $self->config_data( 'inline_auto_include' => $self->alien_inline_auto_include );
 
-  if (grep /(?<!\%)\%c/, @{ $self->alien_build_commands }) {
-    $self->config_data( 'autoconf' => 1 );
-  }
+  if($Force || !$self->alien_check_installed_version) {
+    if (grep /(?<!\%)\%c/, @{ $self->alien_build_commands }) {
+      $self->config_data( 'autoconf' => 1 );
+    }
 
-  if ($^O eq 'MSWin32' && ($self->config_data( 'autoconf') || $self->alien_msys)) {
-    $self->_add_prereq( 'build_requires', 'Alien::MSYS', '0' );
-    $self->config_data( 'msys' => 1 );
-  } else {
-    $self->config_data( 'msys' => 0 );
-  }
+    if ($^O eq 'MSWin32' && ($self->config_data( 'autoconf') || $self->alien_msys)) {
+      $self->_add_prereq( 'build_requires', 'Alien::MSYS', '0' );
+      $self->config_data( 'msys' => 1 );
+    } else {
+      $self->config_data( 'msys' => 0 );
+    }
   
-  while(my($tool, $version) = each %{ $self->alien_bin_requires }) {
-    $self->_add_prereq( 'build_requires', $tool, $version );
+    while(my($tool, $version) = each %{ $self->alien_bin_requires }) {
+      $self->_add_prereq( 'build_requires', $tool, $version );
+    }
   }
 
 
@@ -267,6 +272,7 @@ sub ACTION_alien_code {
   $self->alien_init_temp_dir;
 
   $self->config_data( name => $self->alien_name );
+  $self->config_data( ffi_name => $self->alien_ffi_name );
 
   my $version;
   $version = $self->alien_check_installed_version
@@ -1074,10 +1080,6 @@ in C<Module::Build::API>.
  
 =back
 
-=head1 AUTHOR
-
-Joel Berger <joel.a.berger@gmail.com>
-
 =head1 SEE ALSO
 
 =over
@@ -1102,11 +1104,13 @@ L<http://github.com/Perl5-Alien/Alien-Base>
 
 =head1 AUTHOR
 
-Joel Berger, E<lt>joel.a.berger@gmail.comE<gt>
+Original author: Joel Berger, E<lt>joel.a.berger@gmail.comE<gt>
+
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt> and the L<Alien::Base> team
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2014 by Joel Berger
+Copyright (C) 2012-2015 by Joel Berger
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
